<?php

/**
 * @package rgraph Joomla! Plugin
 * @version Version 1
 * @author  Joachim Schmidt - joachim.schmidt@jschmidt-systemberatung.de
 * @copyright (C) 2016 Joachim Schmidt. All rights reserved.
 * @license GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 * @abstract:   json php-helper class for rgraph charts package
 *
 */
namespace rgraph\lib;
// no direct access
defined('_JEXEC') or die('Restricted access');

class plg_rgraph_valid_options
{

    public static function options ($option = null)
    {
        $valid_options = array(
                'debug' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'If set will check setting of options'
                ),
                'origdata' => array(
                        'type' => 'array',
                        'types' => 'array',
                        'default' => 'null',
                        'desc' => 'saved data if log calculated'
                ),
                'bubbleData' => array(
                        'type' => 'array',
                        'types' => 'array',
                        'default' => 'null',
                        'desc' => 'this is the data for bubbles used in bubble charts'
                ),
                'origlabels' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'null',
                        'desc' => 'saved labels if llabels truncated'
                ),
                'bubbleWidth' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => "width of largest bubble in bubble charts."
                ),
                'bubbleMin' => array(
                        'type' => 'double',
                        'default' => 0,
                        'desc' => "lowest data value in bubble charts."
                ),
                'bubbleMax' => array(
                        'type' => 'double',
                        'default' => 0,
                        'desc' => "highest data value in bubble charts."
                ),
                'centerx' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'If required, you can position the Pie chart using this instead of the gutters'
                ),
                'centery' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'If required, you can position the Pie chart using this instead of the gutters'
                ),
                'corners' => array(
                        'type' => 'string',
                        'default' => 'square',
                        'desc' => 'This can be (the default) square or round. When it is set to round the tops of the bars will have rounded corners.'
                ),
                'cornersRoundRadius' => array(
                        'type' => 'integer',
                        'default' => '10',
                        'desc' => 'This is the extent of the rounded corners. Bigger values means rounder corners.'
                ),
                'radius' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'If required, you can size Pie charts and Rose Charts using this instead of the gutters.'
                ),
                'backgroundBarsCount' => array(
                        'type' => 'integer',
                        'default' => '5',
                        'desc' => 'The number of background bars.'
                ),
                'backgroundBarsColor1' => array(
                        'type' => 'string',
                        'default' => 'white (#fff)',
                        'desc' => 'The color of the background bars, (1 of 2)'
                ),
                'backgroundBarsColor2' => array(
                        'type' => 'string',
                        'default' => 'white (#fff)',
                        'desc' => 'The color of the background bars, (2 of 2)'
                ),
                'backgroundGrid' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'Option whether to show the background grid or not'
                ),
                'backgroundGridColor' => array(
                        'type' => 'string',
                        'default' => '#ddd)',
                        'desc' => 'The color of the background grid'
                ),
                'backgroundGridAlign' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'If you want to have your grid lines line up with the labels (both X and Y axes), you can set this to true and RGraph will attempt to make the grid lines line up. If you have a hmargin set then the alignment will be thrown out.'
                ),
                'backgroundGridHsize' => array(
                        'type' => 'integer',
                        'default' => '40',
                        'desc' => 'The horizontal background grid size'
                ),
                'backgroundGridVsize' => array(
                        'type' => 'integer',
                        'default' => '18',
                        'desc' => 'The vertical background grid size'
                ),
                'backgroundGridLinewidth' => array(
                        'type' => 'double',
                        'default' => '1',
                        'desc' => 'The width that the background grid lines are. Decimals (eg 0.5) are permitted'
                ),
                'backgroundGridBorder' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'Determines whether a border line is drawn around the grid'
                ),
                'backgroundGridHlinesCount' => array(
                        'type' => 'integer',
                        'default' => '5',
                        'desc' => 'When using autofit this allows you to specify how many horizontal grid lines you want.'
                ),
                'backgroundGridHlines' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'Determines whether to draw the horizontal grid lines.'
                ),
                'backgroundGridVlinesCount' => array(
                        'type' => 'integer',
                        'default' => '20',
                        'desc' => 'When using autofit this allows you to specify how many vertical grid lines you want.'
                ),
                'backgroundGridVlines' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'Determines whether to draw the vertical grid lines.'
                ),
                'backgroundGridRadials' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'To control the number of \'spokes that the background grd has you can use this property.'
                ),
                'backgroundGridRadialsCount' => array(
                        'type' => 'integer',
                        'default' => '5 (linked to how many scale labels are shown)',
                        'desc' => 'How many circular grid lines are drawn.'
                ),
                'backgroundGridRadialsOffset' => array(
                        'type' => 'integer',
                        'default' => '0 ',
                        'desc' => 'The offset that is applied to the background grid radial lines (this is measured in radians).'
                ),
                'backgroundGridCircles' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'Whether the background grid circles (or angular lines) are drawn'
                ),
                'backgroundGridCirclesCount' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'Using this option you can specify the exact number of background circles'
                ),
                'backgroundGridAutofit' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'Instead of specifying a pixel width/height for the background grid, you can use autofit and specify how many horizontal and vertical lines you want.'
                ),
                'backgroundGridDotted' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'If you want to have your background grid dotted then set this to true. This takes precedence over dashed lines'
                ),
                'backgroundGridDashed' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'If you want to have your background grid dashed then set this to true.'
                ),
                'backgroundHbars' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'null',
                        'desc' => 'An array of information stipulating horizontal coloured bars. You can use these to indicate limits. Eg: myBar.set(\'hbars\', [[75, 10, \'yellow\'], [85, 15, \'red\']]); This would give you two bars, one red and a lower yellow bar. The units correspond to your scale, and are the starting point and the height.'
                ),
                'backgroundVbars' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'null',
                        'desc' => 'An array of information stipulating Vertical coloured bars. You can use these to indicate limits. Eg: myBar.set(\'hbars\', [[75, 10, \'yellow\'], [85, 15, \'red\']]); This would give you two bars, one red and a lower yellow bar. The units correspond to your scale, and are the starting point and the height.'
                ),
                'backgroundImage' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'If you want to specify a background image to use on your chart, specify it with this property.'
                ),
                'backgroundImageStretch' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'By default your background image is stretched (if necessary) to cover the whole chart area (gutters not included). If this is not what you want then set this property to false.'
                ),
                'backgroundImageX' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'The X position of the image. The coordinates are the top left corner of the image.'
                ),
                'backgroundImageY' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'The Y position of the image. The coordinates are the top left corner of the image.'
                ),
                'backgroundImageW' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'The width of the image. If you have a large canvas with many charts - you may need to specify this.'
                ),
                'backgroundImageH' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'The height of the image. If you have a large canvas with many charts - you may need to specify this.'
                ),
                'backgroundImageAlign' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'Instead of specifying the coordinates of the image, you can instead simply align it top, bottom, left or right. Examples are:  top left, bottom right, bottom right'
                ),
                'backgroundImageAlpha' => array(
                        'type' => 'double',
                        'default' => '1',
                        'desc' => 'The alpha value (the opacity) of the image.'
                ),
                'backgroundColor' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'If you want to have a single background color for your chart you can use this. It doesn\'t cover the gutters. If you want that then you can simply apply a CSS background color to the canvas tag.'
                ),
                'backdrop' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'When enabled this specifies that the line(s) will have a backdrop effect. You can control the transparency with the other backdrop settings).'
                ),
                'backdropSize' => array(
                        'type' => 'integer',
                        'default' => '30',
                        'desc' => 'This controls the size/extent of the backdrop effect.'
                ),
                'backdropAlpha' => array(
                        'type' => 'double',
                        'default' => '0.2',
                        'desc' => 'This controls how much transparency the backdrop effect has. It can go from 0 - 1.'
                ),
                'backgroundCircles' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'Whether the background circles are shown.'
                ),
                'backgroundCirclesCount' => array(
                        'type' => 'integer',
                        'default' => 'The same as labels.count',
                        'desc' => 'This controls the number of background circles that are shown.'
                ),
                'backgroundCirclesColor' => array(
                        'type' => 'string',
                        'default' => '#ddd',
                        'desc' => 'This is the color of the background circles.'
                ),
                'backgroundCirclesPoly' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Instead of circles the background lines can be polygons instead. So if you have 4 points you get squares, 5 points pentagons, 6 points hexagons and so on.'
                ),
                'backgroundCirclesSpokes' => array(
                        'type' => 'integer',
                        'default' => '24',
                        'desc' => 'This controls how many lines there are that go from the center outwards.'
                ),
                'axes' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'Whether the axes are drawn.'
                ),
                'axesLinewidth' => array(
                        'type' => 'integer',
                        'default' => '1',
                        'desc' => 'The linewidth of the axes.'
                ),
                'xaxis' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'Set this to true if you don\'t want an X axis'
                ),
                'axesTickmarks' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'Whether the axes have tickmarks or not'
                ),
                'yaxis' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'Set this to true if you don\'t want a Y axis'
                ),
                'xaxisLabelsSpecificAlign' => array(
                        'type' => 'boolean',
                        'default' => 'null, With this setting you can center the labels within its section',
                        'desc' => 'If you are using specific points for X labels, by default the labels are left aligned within its section'
                ),
                'xaxisLinewidth' => array(
                        'type' => 'integer',
                        'default' => '1 ',
                        'desc' => 'The linewidth used for the X axis and the X axis tickmarks.'
                ),
                'xaxisColor' => array(
                        'type' => 'string',
                        'default' => 'black ',
                        'desc' => 'The color of the X axis (and its tickmarks.'
                ),
                'xaxisTickmarksLastLeft' => array(
                        'type' => 'boolean',
                        'default' => 'null ',
                        'desc' => 'Whether the last tickmark on the left is displayed.'
                ),
                'xaxisTickmarksLastRight' => array(
                        'type' => 'boolean',
                        'default' => 'null ',
                        'desc' => 'Whether the last tickmark on the right is displayed.'
                ),
                'xaxisTickmarksLength' => array(
                        'type' => 'integer',
                        'default' => '3 ',
                        'desc' => 'The length of the tickmarks.'
                ),
                'xaxisTickmarksInterval' => array(
                        'type' => 'integer',
                        'default' => 'null ',
                        'desc' => 'The X tickmark interval.'
                ),
                'xaxisLabelsHalign' => array(
                        'type' => 'string',
                        'default' => 'center ',
                        'desc' => 'The horizontal alignment of the labels.'
                ),
                'xaxisLabelsValign' => array(
                        'type' => 'string',
                        'default' => 'top ',
                        'desc' => 'The vertical alignment of the labels.'
                ),
                'xaxisLabelsPosition' => array(
                        'type' => 'string',
                        'default' => 'section ',
                        'desc' => 'This property controls how the labels are arranged - section for most chart types and edge for Line charts. You probably won\'t need to change this.'
                ),
                'xaxisTitleOffsetx' => array(
                        'type' => 'integer',
                        'default' => '0 ',
                        'desc' => 'The X pixel offset that\'s applied to the title.'
                ),
                'xaxisTitleOffsety' => array(
                        'type' => 'integer',
                        'default' => '0 ',
                        'desc' => 'The Y pixel offset that\'s applied to the title.'
                ),
                'xaxisTitleHalign' => array(
                        'type' => 'string',
                        'default' => 'center ',
                        'desc' => 'The horizontal alignment of the title.'
                ),
                'xaxisTitleValign' => array(
                        'type' => 'string',
                        'default' => 'top ',
                        'desc' => 'The vertical alignment of the title.'
                ),
                'xaxisScaleUnitsPre' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The units that the X axis is measured in. This string is displayed before the actual number, allowing you to specify values such as €50.'
                ),
                'xaxisScaleUnitsPost' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The units that the X axis is measured in. This string is displayed after the actual number, allowing you to specify values such as 50ms.'
                ),
                'xaxisScaleDecimals' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'The number of decimal places to display for the X scale'
                ),
                'xaxisScalePoint' => array(
                        'type' => 'string',
                        'default' => '.',
                        'desc' => 'The character used as the decimal point'
                ),
                'xaxisScaleThousand' => array(
                        'type' => 'string',
                        'default' => ',',
                        'desc' => 'The character used as the thousand separator'
                ),
                'xaxisScaleRound' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether to round the maximum scale value up or not. This will produce slightly better scales in some instances.'
                ),
                'xaxisScaleZerostart' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Whether the scale starts at zero or not'
                ),
                'xaxisScaleMax' => array(
                        'type' => 'double',
                        'default' => 'none (one is calculated)',
                        'desc' => '(Optional) An optional max figure for the X scale'
                ),
                'xmax' => array(
                        'type' => 'double',
                        'default' => 'none (one is calculated)',
                        'desc' => '(Optional) An optional max figure for the X scale'
                ),
                'xaxisScaleMin' => array(
                        'type' => 'double',
                        'default' => '0',
                        'desc' => 'An optional minimum figure for the X scale'
                ),
                'xmin' => array(
                        'type' => 'double',
                        'default' => '0',
                        'desc' => 'An optional minimum figure for the X scale'
                ),
                'xaxisScale' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'If true then an X scale is drawn instead of X labels'
                ),
                'xaxisScaleFormatter' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'This can be a function, which is passed the object and the number and should return a formatted number (formatted as you wish)'
                ),
                'xaxisScaleLabelsCount' => array(
                        'type' => 'integer',
                        'default' => '10',
                        'desc' => 'This is a number representing how many X labels there should be when you\'re using the X scale'
                ),
                'xaxisTickmarks' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Using this property you can turn off the X tickmarks'
                ),
                'yaxisTickmarks' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'Using this property you can turn off the Y tickmarks'
                ),
                'axesColor' => array(
                        'type' => 'string',
                        'default' => 'black',
                        'desc' => 'The color of the axes'
                ),
                'labels' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'empty array',
                        'desc' => 'An array of the labels for the chart.'
                ),
                'xaxisLabels' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'empty array',
                        'desc' => 'An array of the X labels for the chart.'
                ),
                'xaxisLabelsFont' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The font used to render the X axis labels.'
                ),
                'xaxisLabelsColor' => array(
                        'type' => 'string',
                        'default' => 'null (defaults to textColor)',
                        'desc' => 'The color of the X axis labels'
                ),
                'xaxisLabelsSize' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'The size of the X axis labels.'
                ),
                'xaxisLabelsBold' => array(
                        'type' => 'boolean',
                        'default' => 'null (defaults to textBold)',
                        'desc' => 'Whether the X axis labels are bold or not'
                ),
                'xaxisLabelsItalic' => array(
                        'type' => 'boolean',
                        'default' => 'null (defaults to textItalic)',
                        'desc' => 'Whether the X axis labels are italic or not'
                ),
                'xaxisLabelsAngle' => array(
                        'type' => 'double',
                        'default' => 'This can be from 90 to -90 degrees',
                        'desc' => 'The angle of the X axis labels'
                ),
                'xaxisLabelsOffsetx' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'This allows you finer grained control in the horizontal direction over the X label positioning if you need it.'
                ),
                'xaxisLabelsOffsety' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'This allows you finer grained control in the vertical direction over the X label positioning if you need it.'
                ),
                'xaxisLabelsCount' => array(
                        'type' => 'integer',
                        'default' => '5',
                        'desc' => 'This determines how many labels are shown on the scale'
                ),
                'xaxisTitle' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'This allows you to specify a title for the X axis'
                ),
                'xaxisTitleSize' => array(
                        'type' => 'integer',
                        'default' => 'null (defaults to the textSize setting)',
                        'desc' => 'This allows you to specify a size for the X axis title'
                ),
                'xaxisTitleFont' => array(
                        'type' => 'string',
                        'default' => 'null (defaults to the textFont setting)',
                        'desc' => 'This allows you to specify a font for the X axis title'
                ),
                'xaxisTitleBold' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'This controls whether the X axis title is bold or not'
                ),
                'xaxisTitleItalic' => array(
                        'type' => 'boolean',
                        'default' => 'null (defaults to the textItalic setting)',
                        'desc' => 'This controls whether the X axis title is italic or not'
                ),
                'xaxisTitleColor' => array(
                        'type' => 'string',
                        'default' => 'null (defaults to the textColor setting)',
                        'desc' => 'This controls the color of the X axis title'
                ),
                'xaxisTitleX' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'By giving this you can specifically set the X position of the X axis title'
                ),
                'xaxisTitleY' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'By giving this you can specifically set the Y position of the X axis title'
                ),
                'xaxisTitlePos' => array(
                        'type' => 'double',
                        'default' => '0.25',
                        'desc' => 'This is multiplied with the margin to give the position of the X axis title'
                ),
                'xaxisTickmarksCount' => array(
                        'type' => 'integer',
                        'default' => 'null (linked to number of data points)',
                        'desc' => 'The number of X tickmarks'
                ),
                'xaxisPosition' => array(
                        'type' => 'string',
                        'default' => 'It can be bottom, center or top',
                        'desc' => 'The position of the X axis'
                ),
                'yaxisScale' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'Can be true or false and determines whether the chart has Y axis labels'
                ),
                'yaxisScaleFormatter' => array(
                        'type' => 'string',
                        'default' => 'This function should handle ALL of the formatting',
                        'desc' => 'To allow thoroughly custom formats of numbers in the scale, you can use this option to specify a function that is used by RGraph to format numbers'
                ),
                'yaxisScaleMin' => array(
                        'type' => 'double',
                        'default' => 'null',
                        'desc' => '	The optional minimum Y scale value. If not specified then it will be zero.'
                ),
                'yaxisScaleMax' => array(
                        'type' => 'double',
                        'default' => 'null',
                        'desc' => '	The optional maximum Y scale value. If not specified then it will be calculated.'
                ),
                'ymax' => array(
                        'type' => 'double',
                        'default' => 'null',
                        'desc' => '	The optional maximum Y scale value. If not specified then it will be calculated.'
                ),
                'ymin' => array(
                        'type' => 'double',
                        'default' => 'null',
                        'desc' => '	The optional maximum Y scale value. If not specified then it will be calculated.'
                ),
                'yaxisLabels' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'true',
                        'desc' => 'Can be true or false and determines whether the chart has Y axis labels'
                ),
                'yaxisLabelsCount' => array(
                        'type' => 'integer',
                        'default' => 'Formerly this could be 1/3/5/10 but now it can be any number',
                        'desc' => 'A value that controls how many Y labels there are'
                ),
                'yaxisLabelsFont' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The font used for the Y axis text'
                ),
                'yaxisLabelsSize' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'The size used for the Y axis text'
                ),
                'yaxisLabelsColor' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The color used for the Y axis text'
                ),
                'yaxisLabelsBold' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the Y axis text is bold or not'
                ),
                'yaxisLabelsItalic' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the Y axis text is italic or not'
                ),
                'yaxisLabelsSpecific' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'null',
                        'desc' => 'You can use this option to give your own Y labels (eg [\'Low\', \'Medium\', \'High\']. Note: Since March 2013 you may now need to add an extra (optionally) empty element to the array of labels to achieve your desired result. '
                ),
                'yaxisLabelsOffsetx' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'This allows you finer grained control in the horizontal direction over the Y label positioning if you need it'
                ),
                'yaxisLabelsOffsety' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'This allows you finer grained control in the vertical direction over the Y label positioning if you need it'
                ),
                'yaxisLinewidth' => array(
                        'type' => 'integer',
                        'default' => '1 ',
                        'desc' => 'The linewidth of the Y axis.'
                ),
                'yaxisColor' => array(
                        'type' => 'string',
                        'default' => 'black ',
                        'desc' => 'The color of the Y axis.'
                ),
                'yaxisTickmarksLength' => array(
                        'type' => 'integer',
                        'default' => '3 ',
                        'desc' => 'The length of the Y axis tickmarks.'
                ),
                'yaxisTickmarksLastTop' => array(
                        'type' => 'boolean',
                        'default' => 'null (displayed if the X axis position warrants it) ',
                        'desc' => 'Whether the top-most tickmark is drawn.'
                ),
                'yaxisTickmarksLastBottom' => array(
                        'type' => 'boolean',
                        'default' => 'null (displayed if the X axis position warrants it) ',
                        'desc' => 'Whether the bottom-most tickmark is drawn.'
                ),
                'yaxisLabelsPosition' => array(
                        'type' => 'string',
                        'default' => 'edge ',
                        'desc' => 'This controls how the specific labels are positioned on the Y axis. It has no effect on a scale.'
                ),
                'yaxisLabelsHalign' => array(
                        'type' => 'integer',
                        'default' => 'null ',
                        'desc' => 'The horizontal alignment of the Y axis labels.'
                ),
                'yaxisLabelsValign' => array(
                        'type' => 'integer',
                        'default' => 'null ',
                        'desc' => 'The vertical alignment of the Y axis labels.'
                ),
                'yaxisTitleOffsetx' => array(
                        'type' => 'integer',
                        'default' => '0 ',
                        'desc' => 'The pixel offset that\'s added to the Y axis titles X coordinate.'
                ),
                'yaxisTitleOffsety' => array(
                        'type' => 'integer',
                        'default' => '0 ',
                        'desc' => 'The pixel offset that\'s added to the Y axis titles Y coordinate.'
                ),
                'yaxisTitleHalign' => array(
                        'type' => 'integer',
                        'default' => '0 ',
                        'desc' => 'The horizontal alignment of the Y axis title.'
                ),
                'yaxisTitleValign' => array(
                        'type' => 'integer',
                        'default' => '0 ',
                        'desc' => 'The vertical alignment of the Y axis title.'
                ),
                'yaxisTitle' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'This allows you to specify a title for the Y axis'
                ),
                'yaxisTitleSize' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'This allows you to specify a size for the Y axis title'
                ),
                'yaxisTitleFont' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'This allows you to specify a font for the Y axis title'
                ),
                'yaxisTitleBold' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'This controls whether the Y axis title is bold or not'
                ),
                'yaxisTitleItalic' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'This controls whether the Y axis title is italic or not'
                ),
                'yaxisTitleColor' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'This controls what color the Y axis is'
                ),
                'yaxisTitlePos' => array(
                        'type' => 'double',
                        'default' => '0.25',
                        'desc' => 'This is multiplied with the margin to give the position of the Y axis title'
                ),
                'yaxisTitleX' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'By giving this you can specifically set the X position of the Y axis title'
                ),
                'yaxisTitleY' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'By giving this you can specifically set the Y position of the Y axis title'
                ),
                'yaxisScaleUnitsPost' => array(
                        'type' => 'string',
                        'default' => 'none',
                        'desc' => 'The units (if any) that the Y axis is measured in (gets appended to the number)'
                ),
                'yaxisScaleUnitsPre' => array(
                        'type' => 'string',
                        'default' => 'none',
                        'desc' => 'The units (if any) that the Y axis is measured in (gets prepended to the number)'
                ),
                'yaxisScaleDecimals' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'Determines the precision of the numbers used as the scale'
                ),
                'yaxisScalePoint' => array(
                        'type' => 'string',
                        'default' => '.',
                        'desc' => 'The character used as the decimal point'
                ),
                'yaxisScaleThousand' => array(
                        'type' => 'string',
                        'default' => ',',
                        'desc' => 'The character used as the thousand separator'
                ),
                'yaxisScaleRound' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Whether to round the maximum scale value up or not. This will produce slightly better scales in some instances.'
                ),
                'yaxisScaleInvert' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Reverses the Y axis scale so that the minimum value is at the top, instead of the bottom'
                ),
                'yaxisTickmarksCount' => array(
                        'type' => 'integer',
                        'default' => '10',
                        'desc' => 'The number of Y tickmarks'
                ),
                'yaxisPosition' => array(
                        'type' => 'string',
                        'default' => 'left, Can be left or right',
                        'desc' => 'Specifies the Y axis position'
                ),
                'colors' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'An array - [\'rgb(0,0,255)\', \'#0f0\', \'#00f\', \'#ff0\', \'#0ff\', \'#0f0\']',
                        'desc' => 'Array of the colors for a chart'
                ),
                'colorsDefault' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The default color of bars. If you don\'t specify a color for the event, this will be used.'
                ),
                'colorsAlpha' => array(
                        'type' => 'double',
                        'default' => 'null',
                        'desc' => 'If set (a number between 0 nd 1), this will be used as the alpha value (opacity) of the colors of the chart.'
                ),
                'colorsAlternate' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Set this to true if you want your line color(s) to be alternated'
                ),
                'colorsConnectors' => array(
                        'type' => 'string',
                        'default' => '#666',
                        'desc' => 'This is the color used for the connectors between the waterfall bars. Set this to rgba(0,0,0,0) if you do not want the connectors to be visible.'
                ),
                'colorsRedStart' => array(
                        'type' => 'integer',
                        'default' => '90% of the max',
                        'desc' => 'The point at which the red area starts'
                ),
                'colorsRedColor' => array(
                        'type' => 'string',
                        'default' => '#DC3912',
                        'desc' => 'The red color'
                ),
                'colorsRedWidth' => array(
                        'type' => 'integer',
                        'default' => '10',
                        'desc' => 'The width of the red area'
                ),
                'colorsYellowColor' => array(
                        'type' => 'string',
                        'default' => '#FF9900',
                        'desc' => 'The yellow color'
                ),
                'colorsYellowWidth' => array(
                        'type' => 'integer',
                        'default' => '10',
                        'desc' => 'The width of the yellow area'
                ),
                'colorsGreenStart' => array(
                        'type' => 'integer',
                        'default' => '35% of the maximum value',
                        'desc' => 'The value that the green area should begin at'
                ),
                'colorsGreenMax' => array(
                        'type' => 'double',
                        'default' => '75% of the maximum value',
                        'desc' => 'This is the point at which the green area ends'
                ),
                'colorsRedMin' => array(
                        'type' => 'double',
                        'default' => 'The yellow area is between the green and red areas',
                        'desc' => 'This is the point at which the red area starts'
                ),
                'colorsYellowStart' => array(
                        'type' => 'integer',
                        'default' => '10% of the maximum value',
                        'desc' => 'The value that the yellow area should begin at'
                ),
                'colorsYellowEnd' => array(
                        'type' => 'integer',
                        'default' => '35% of the maximum value',
                        'desc' => 'The value that the yellow area should end at'
                ),
                'colorsRedEnd' => array(
                        'type' => 'integer',
                        'default' => '10% of the maximum value',
                        'desc' => 'The value that the red area should end at'
                ),
                'colorsGreenEnd' => array(
                        'type' => 'integer',
                        'default' => '70% of the max',
                        'desc' => 'The point at which the green area ends'
                ),
                'colorsGreenColor' => array(
                        'type' => 'string',
                        'default' => 'rgba(0,0,0,0)',
                        'desc' => 'The green color'
                ),
                'colorsGreenWidth' => array(
                        'type' => 'integer',
                        'default' => '10',
                        'desc' => 'The width of the red area'
                ),
                'colorsSequential' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'If true, for regular bar charts, (not stacked or grouped), the colors that you specify will be used in a sequential fashion.'
                ),
                'colorsStroke' => array(
                        'type' => 'string',
                        'default' => 'rgba(0,0,0,0)',
                        'desc' => 'The color of the outlines of the bars'
                ),
                'colorsBubbleGraduated' => array(
                        'type' => 'boolean',
                        'default' => 'true, By setting this to false you can disable the gradients and use flat colors',
                        'desc' => 'By default the Bubble chart bubbles are graduated in color'
                ),
                'colorsLeft' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'null',
                        'desc' => 'Use this property to specify an array of colors that are used just for the left-hand-side bars. This property can be used instead of the colors property.'
                ),
                'colorsRight' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'null',
                        'desc' => 'Use this property to specify an array of colors that are used just for the right-hand-side bars. This property can be used instead of the colors property.'
                ),
                'filled' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Whether the area under the line is filled or not. This looks best when there is no horizontal margin'
                ),
                'filledAccumulative' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'When showing multiple filled lines the values are by default accumulative (ie added to each other). If this is not the desired behaviour, then you can set this property to false to have them drawn \'non-accumulatively\'.'
                ),
                'filledRange' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'This is useful for indicating a range. Exactly two datasets are required, with the space between them filled. This is useful for indicating a range.'
                ),
                'filledRangeThreshold' => array(
                        'type' => 'double',
                        'default' => 'null',
                        'desc' => 'When drawing a filled range chart you set a threshhold in the case where you want the range to be one color above the threshold and another below.'
                ),
                'filledRangeThresholdColors' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => '[\'red\', \'green\']',
                        'desc' => 'This is a two element array that defines the colors when using a dual color range chart.'
                ),
                'filledColors' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'null',
                        'desc' => 'A single color or an array of colors that filled line charts will use'
                ),
                'fillTooltips' => array(
                        'type' => 'array',
                        'types' => 'boolean',
                        'default' => 'null ',
                        'desc' => 'An array of tooltips that are triggered when you click on the fill of each dataset (not the points).'
                ),
                'fillMousemove' => array(
                        'type' => 'string',
                        'default' => 'null ',
                        'desc' => 'A function which handles the mousemove event when over the fill.'
                ),
                'fillClick' => array(
                        'type' => 'string',
                        'default' => 'null ',
                        'desc' => 'A function which handles the click event when over the fill.'
                ),
                'fillHighlightFill' => array(
                        'type' => 'string',
                        'default' => 'rgba(255,255,255,0.7) ',
                        'desc' => 'The color used as the fill for the highlight.'
                ),
                'fillHighlightStroke' => array(
                        'type' => 'string',
                        'default' => 'rgba(0,0,0,0) ',
                        'desc' => 'The color used as the stroke for the highlight.'
                ),
                'fillMousemoveRedraw' => array(
                        'type' => 'boolean',
                        'default' => 'false ',
                        'desc' => 'Whether to redraw the chart when the mouse moves. You probably won\'t need this option.'
                ),
                'anglesStart' => array(
                        'type' => 'double',
                        'default' => 'null',
                        'desc' => 'For Gauge or Meter charts if you want the chart to start at an angle other than the north axis - you can use this. (keep in mind that this is specified in RADIANS).'
                ),
                'anglesEnd' => array(
                        'type' => 'double',
                        'default' => 'null',
                        'desc' => 'For Gauge or Meter charts you can specify the angle that the Gauge should end at with this property.'
                ),
                'backgroundGradient' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'If true then a subtle gradient is drawn over the background. Alternatively you can leave this as false and set the background color to your own gradient.'
                ),
                'backgroundImageUrl' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'For Meter charts The URL of an image that is used as the background for the Meter. If you use a background image you can create some significantly different looking Meters.'
                ),
                'backgroundImageOffsetx' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'For Meter charts By default the image is positioned at [0,0] (the top left of the canvas) - you can use this to move the image left (negative) or right (positive).'
                ),
                'backgroundImageOffsety' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'For Meter charts By default the image is positioned at [0,0] (the top left of the canvas) - you can use this to move the image up (negative) or down (positive).'
                ),
                'borderColor1' => array(
                        'type' => 'string',
                        'default' => '#BEBCB0',
                        'desc' => 'For odometer charts this is the first color used in the gradient of the outer border of the chart (if enabled).'
                ),
                'borderColor2' => array(
                        'type' => 'string',
                        'default' => '#BEBCB0',
                        'desc' => 'For odometer charts this is the second color used in the gradient of the outer border of the chart (if enabled).'
                ),
                'borderColor3' => array(
                        'type' => 'string',
                        'default' => '#BEBCB0',
                        'desc' => 'For odometer charts this is the third color used in the gradient of the outer border of the chart (if enabled).'
                ),
                'textValign' => array(
                        'type' => 'string',
                        'default' => 'center',
                        'desc' => 'The vertcal alignment of the text. In some cases you may want to change this to bottom'
                ),
                'titleTop' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The top title of a Gauge chart, if any.'
                ),
                'titleBottom' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The bottom title of a Gauge chart, if any.'
                ),
                'titleTopFont' => array(
                        'type' => 'string',
                        'default' => 'Arial',
                        'desc' => 'The font of a Gauge chart that the title is rendered in. If not specified the text.font setting is used (usually Arial)'
                ),
                'titleBottomFont' => array(
                        'type' => 'string',
                        'default' => 'Arial',
                        'desc' => 'The font of a Gauge chart that the title is rendered in. If not specified the text.font setting is used (usually Arial)'
                ),
                'titleTopSize' => array(
                        'type' => 'integer',
                        'default' => '14',
                        'desc' => 'The font size of the title of a Gauge chart. If not specified the size is usually 2pt bigger than the text.size setting.'
                ),
                'titleBottomSize' => array(
                        'type' => 'integer',
                        'default' => '14',
                        'desc' => 'The font size of the title of a Gauge chart. If not specified the size is usually 2pt bigger than the text.size setting.'
                ),
                'titleTopBold' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'Whether the title of a Gauge chart is bold or not.'
                ),
                'titleBottomBold' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'Whether the title of a Gauge chart is bold or not.'
                ),
                'titleTopColor' => array(
                        'type' => 'string',
                        'default' => '#333',
                        'desc' => 'The color of the title of a Gauge chart.'
                ),
                'titleBottomColor' => array(
                        'type' => 'string',
                        'default' => '#333',
                        'desc' => 'The color of the title of a Gauge chart.'
                ),
                'titleTopPos' => array(
                        'type' => 'double',
                        'default' => 'null',
                        'desc' => 'For Gauge chart if set this number is multiplied with the radius to give the Y position of the title. This allows to totally override the Y position of the title.'
                ),
                'titleBottomPos' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'For Gauge chart If set this number is multiplied with the radius to give the Y position of the title. This allows to totally override the Y position of the title.'
                ),
                'titleTopItalic' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the top title is italic or not'
                ),
                'titleBottomItalic' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the bottom title is italic or not'
                ),
                'titleHalign' => array(
                        'type' => 'string',
                        'default' => 'center (can change depending on other options) ',
                        'desc' => 'The horizontal alignment of the title.'
                ),
                'titleValign' => array(
                        'type' => 'string',
                        'default' => 'center (can change depending on other options) ',
                        'desc' => 'The vertical alignment of the title.'
                ),
                'borderOuter' => array(
                        'type' => 'string',
                        'default' => '#ccc',
                        'desc' => 'This is the color of the outer border.'
                ),
                'borderInner' => array(
                        'type' => 'string',
                        'default' => '#f1f1f1',
                        'desc' => 'This is the color of the inner border.'
                ),
                'borderOutline' => array(
                        'type' => 'string',
                        'default' => 'black',
                        'desc' => 'This is the color of the border around the Gauge.'
                ),
                'colorsRanges' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'null',
                        'desc' => 'With this you can totally control the colors used on the chart - eg [[-100,-90, \'red\'], [-90, -70,\'yellow\'], [-70, 70, \'#0f0\'], [70, 90, \'yellow\'], [90,100,\'red\']].'
                ),
                'needleTail' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Whether the tail for the needle is shown.'
                ),
                'needleHead' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'This controls whether the arrow head on the end of the needle is displayed.'
                ),
                'needleHeadWidth' => array(
                        'type' => 'double',
                        'default' => '0.088 ',
                        'desc' => 'The width of the needle head. Keep in mind that this is measured in radians and not pixels.'
                ),
                'needleHeadLength' => array(
                        'type' => 'integer',
                        'default' => '30 ',
                        'desc' => 'The length of the needle head. Keep in mind that if you set this too high the line beneath the pointer may show through.'
                ),
                'needleRadius' => array(
                        'type' => 'double',
                        'default' => 'null',
                        'desc' => 'This can be used to stipulate the radius of the pointer.'
                ),
                'needleSize' => array(
                        'type' => 'array',
                        'types' => 'integer',
                        'default' => 'null',
                        'desc' => 'This is the size of the needle(s).'
                ),
                'needleLinewidth' => array(
                        'type' => 'array',
                        'types' => 'integer',
                        'default' => 'null',
                        'desc' => 'This can be used to specify the linewidth used when drawing the needle.'
                ),
                'needleColor' => array(
                        'type' => 'string',
                        'default' => 'red',
                        'desc' => 'For Gauge Charts the color of the needle (not including the bulb at the bottom). Note that this is NOT an array - it\'s just a string.'
                ),
                'needleColors' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => ' [\'#D5604D\', \'red\', \'green\', \'yellow\']',
                        'desc' => 'This is the color(s) of the needle(s).'
                ),
                'needleType' => array(
                        'type' => 'string',
                        'default' => 'triangle',
                        'desc' => 'This controls the appearance of the needles. It can be triangle or line.'
                ),
                'needleTriangleBorder' => array(
                        'type' => 'string',
                        'default' => '#aaa',
                        'desc' => 'This controls the colour of the border for the pointer. If you don\'t want it you could set it to be transparent - rgba(0,0,0,0).'
                ),
                'needleImageUrl' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'If you want to use an image for the needle then you can using this property. Combined with the background image this can make some significantly different looking Meters.'
                ),
                'needleImageOffsetx' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'As \'needleImageOffsetx\' but for the needles Y positioning.'
                ),
                'needleImageOffsety' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'As for needleImageOffsetx but for the needles Y positioning.'
                ),
                'needleWidth' => array(
                        'type' => 'integer',
                        'default' => '2',
                        'desc' => 'Needle images are drawn so that the top left of the needle image is the centerx/centery of the Meter chart (when the needle is horizontal and pointing to the right). You\'ll probably want to center your needle image and you can do so with these properties. Centering is best done when the needle is pointing right. So if you haven\'t changed the angles this will be when the Meters value is the maximum value. If you have changed the angles then you\'ll have to pick a suitable value so the needle is pointing right.'
                ),
                'needleExtra' => array(
                        'type' => 'array',
                        'types' => 'integer',
                        'default' => 'null',
                        'desc' => 'With this you can specify a number of extra pointers that will be drawn on the Odometer. An example would be a meter that\'s used to show upload and download data.'
                ),
                'centerpinColor' => array(
                        'type' => 'string',
                        'default' => 'blue',
                        'desc' => 'This is the color used in the centerpin gradient coloring.'
                ),
                'centerpinRadius' => array(
                        'type' => 'double',
                        'default' => 'null',
                        'desc' => 'This is ths radius of the centerpin.'
                ),
                'borderWidth' => array(
                        'type' => 'integer',
                        'default' => '10',
                        'desc' => 'The width of the border that goes around the Gauge.'
                ),
                'tickmarksSize' => array(
                        'type' => 'integer',
                        'default' => '3',
                        'desc' => 'The size of the tickmarks'
                ),
                'tickmarksSmallCount' => array(
                        'type' => 'integer',
                        'default' => '100',
                        'desc' => 'This controls the number of small tickmarks'
                ),
                'tickmarksLargeCount' => array(
                        'type' => 'integer',
                        'default' => '10',
                        'desc' => 'This controls the number of large tickmarks'
                ),
                'tickmarksSmall' => array(
                        'type' => 'integer',
                        'default' => '25',
                        'desc' => 'The number of small tickmarks on the chart.'
                ),
                'tickmarksSmallColor' => array(
                        'type' => 'string',
                        'default' => 'black',
                        'desc' => 'The color of the small tickmarks on the chart.'
                ),
                'tickmarksHighlighted' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'This controls whether the tickmarks are highlighted in red/yellow/green.'
                ),
                'border' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'Whether the outline is drawn.'
                ),
                'borderGradient' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'This determines whether the Gauge chart has a graduated border. Note: This can cause effects to run slowly in some browsers.'
                ),
                'linewidthSegments' => array(
                        'type' => 'integer',
                        'default' => '1',
                        'desc' => 'The linewidth of the lines separating the segments.'
                ),
                'segmentsRadiusStart' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'Instead of the segments going from the center point outwards, you can use this to specify a start point of the coloured segments.'
                ),
                'shadowInner' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Whether a drop shadow is applied to the inner circle of the Odometer.'
                ),
                'shadowInnerColor' => array(
                        'type' => 'string',
                        'default' => 'black',
                        'desc' => 'The color of the inner shadow.'
                ),
                'shadowInnerOffsetx' => array(
                        'type' => 'integer',
                        'default' => '3',
                        'desc' => 'The X offset of the inner shadow.'
                ),
                'shadowInnerOffsety' => array(
                        'type' => 'integer',
                        'default' => '3',
                        'desc' => 'The Y offset of inner the shadow.'
                ),
                'shadowInnerBlur' => array(
                        'type' => 'integer',
                        'default' => '6',
                        'desc' => 'The severity of the shadow blurring effect.'
                ),
                'shadowOuter' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Whether a drop shadow is applied to the whole Odometer.'
                ),
                'shadowOuterColor' => array(
                        'type' => 'string',
                        'default' => 'black',
                        'desc' => 'The color of the outer shadow.'
                ),
                'shadowOuterOffsetx' => array(
                        'type' => 'integer',
                        'default' => '3',
                        'desc' => 'The X offset of the outer shadow.'
                ),
                'shadowOuterOffsety' => array(
                        'type' => 'integer',
                        'default' => '3',
                        'desc' => 'The Y offset of outer the shadow.'
                ),
                'shadowOuterBlur' => array(
                        'type' => 'integer',
                        'default' => '6',
                        'desc' => 'The severity of the shadow blurring effect.'
                ),
                'line' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'If true the points will be connected by a line.'
                ),
                'linecap' => array(
                        'type' => 'string',
                        'default' => 'round',
                        'desc' => '	This property allows you to set the style for the context.lineCap setting. It can be butt, round or square'
                ),
                'linejoin' => array(
                        'type' => 'string',
                        'default' => 'round',
                        'desc' => 'This property allows you to set the style for the context.lineJoin setting. It can be bevel round or miter.'
                ),
                'lineClose' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'If true then the line will be closed (ie last point connects back to the first point).'
                ),
                'lineLinewidth' => array(
                        'type' => 'double',
                        'default' => '1',
                        'desc' => 'The linewidth of the line.'
                ),
                'lineColors' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => '[\'black\']',
                        'desc' => 'The color(s) of the line(s).'
                ),
                'lineShadow' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Whether the lines have a shadow.'
                ),
                'lineShadowColor' => array(
                        'type' => 'string',
                        'default' => 'black',
                        'desc' => 'The color of the shadow.'
                ),
                'lineShadowOffsetx' => array(
                        'type' => 'integer',
                        'default' => '3',
                        'desc' => 'The horizontal offset of the shadow.'
                ),
                'lineShadowOffsety' => array(
                        'type' => 'integer',
                        'default' => '3',
                        'desc' => 'The vertical offset of the shadow.'
                ),
                'lineShadowBlur' => array(
                        'type' => 'integer',
                        'default' => '2',
                        'desc' => 'The severity of the shadow blurring effect.'
                ),
                'lineStepped' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Like the line chart, Scatter chart lines can be stepped by setting this to true'
                ),
                'nullBridge' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Whether the line of a line chart bridged, if data contains null values'
                ),
                'nullBridgeLinewidth' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'This is the line width for null data line bridges'
                ),
                'nullBridgeColors' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'null',
                        'desc' => 'This is the line color for null data line bridges'
                ),
                'nullBridgeDashArray' => array(
                        'type' => 'array',
                        'types' => 'integer',
                        'default' => 'null',
                        'desc' => 'This sets line shape for null data line bridges to dashed'
                ),
                'nullBridgeLinedash' => array(
                        'type' => 'array',
                        'types' => 'integer',
                        'default' => 'null',
                        'desc' => 'This sets line shape for null data line bridges to dashed'
                ),
                'lineDash' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'With this setting you can control the linedash setting so your lines can be dashed (or dotted).'
                ),
                'dotted' => array(
                        'type' => 'boolean',
                        'default' => 'null, This is a new addition in January 2017 and is thanks to a submission by Garaged',
                        'desc' => 'Whether the line (not the background grid) is dotted or not'
                ),
                'dashed' => array(
                        'type' => 'boolean',
                        'default' => 'null, This is a new addition in January 2017 and is thanks to a submission by Garaged.',
                        'desc' => 'Whether the line (not the background grid) is dashed or not'
                ),
                'boxplotWidth' => array(
                        'type' => 'integer',
                        'default' => '8',
                        'desc' => 'This stipulates the default width of boxes. For more on boxplots.'
                ),
                'boxplotCapped' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'This stipulates whether the boxplot will have caps on the end of whickers. This could be useful if you\'re creating a stock chart for example.'
                ),
                'margin' => array(
                        'type' => 'integer',
                        'default' => '2',
                        'desc' => 'The space above and below each bar.'
                ),
                'marginInnerGrouped' => array(
                        'type' => 'integer',
                        'default' => '1 ',
                        'desc' => 'In a grouped bar chart this is the margin between bars that are on the same group. You can see examples of the marginInnerGrouped in the examples folder of the download archive (eg the demos/bar-grouped2.html file).'
                ),
                'marginLeft' => array(
                        'type' => 'integer',
                        'default' => '25',
                        'desc' => 'The left margin of the chart, (the margin is where the labels and title are))'
                ),
                'marginRight' => array(
                        'type' => 'integer',
                        'default' => '25',
                        'desc' => 'The right margin of the chart, (the margin is where the labels and title are)'
                ),
                'marginTop' => array(
                        'type' => 'integer',
                        'default' => '25',
                        'desc' => 'The top margin of the chart, (the margin is where the labels and title are)'
                ),
                'marginBottom' => array(
                        'type' => 'integer',
                        'default' => '25',
                        'desc' => 'The bottom margin of the chart, (the margin is where the labels and title are)'
                ),
                'marginCenter' => array(
                        'type' => 'integer',
                        'default' => '0 ',
                        'desc' => 'The center area of the chart that the labels sit in. Beginning October 2017 this is now automatically calculated based on the size of the labels. Previously the default was 60.'
                ),
                'marginCenterAuto' => array(
                        'type' => 'boolean',
                        'default' => 'true ',
                        'desc' => 'If true (which is the default) the center margin (where the labels are positioned) will be automatically sized to fit the labels.'
                ),
                'marginLeftAuto' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'If set to true this will automatically size the left margin to accommodate your labels)'
                ),
                'marginRightAuto' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'If set to true this will automatically size the right margin to accommodate your labels)'
                ),
                'marginInner' => array(
                        'type' => 'integer',
                        'default' => '5 ',
                        'desc' => 'The horizontal margin (in pixels) of the chart.'
                ),
                'textColor' => array(
                        'type' => 'string',
                        'default' => 'black',
                        'desc' => 'The color of the labels.'
                ),
                'textSize' => array(
                        'type' => 'integer',
                        'default' => '10',
                        'desc' => 'The size (in points) of the labels.'
                ),
                'textFont' => array(
                        'type' => 'string',
                        'default' => 'Arial',
                        'desc' => 'The font used to render the text.'
                ),
                'textHalign' => array(
                        'type' => 'string',
                        'default' => 'left',
                        'desc' => 'For funnel charts the horizontal alignment of the text. Can be center or left.'
                ),
                'textBold' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'The face of the labels'
                ),
                'textItalic' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'The face of the labels'
                ),
                'textAccessible' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'A new feature in 2016 that allows you to use DOM text in place of canvas text. It makes for much higher quality text that you can also select if desired (for copy/paste operations).'
                ),
                'textAccessibleOverflow' => array(
                        'type' => 'string',
                        'default' => 'visible',
                        'desc' => 'This can be visible or hidden and it controls whether the text is clipped to the edges of the canvas. It defaults to be visible and means you can set small gutters if you wish.'
                ),
                'textAccessiblePointerevents' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'This controls whether the DOM text responds to mouse based events or not (it sets the pointer-events CSS property to none).'
                ),
                'labels' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => '[] empty array',
                        'desc' => 'An array of the labels to be used on the chart.'
                ),
                'labelsEmpty' => array(
                        'type' => 'string',
                        'default' => 'E',
                        'desc' => 'The label used as the empty text.'
                ),
                'labelsFull' => array(
                        'type' => 'string',
                        'default' => 'F',
                        'desc' => 'The label used as the full text.'
                ),
                'labelsBold' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Whether the labels are bold or not'
                ),
                'labelsAxesBold' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'This controls whether the axis labels are bold or not.'
                ),
                'labelsColor' => array(
                        'type' => 'string',
                        'default' => 'null (same as textColor)',
                        'desc' => 'The color of the labels.'
                ),
                'labelsX' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'For funnel charts use this to specify an X position for labels.'
                ),
                'labelsRadiusOffset' => array(
                        'type' => 'integer',
                        'default' => '25 ',
                        'desc' => 'The offset that the circular labels are positioned at.'
                ),
                'labelsSticks' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Stipulates that sticks for the labels are shown. This can also be an array of stick lengths - which may be useful if you\'re experiencing the labels clashing.'
                ),
                'labelsSticksLinewidth' => array(
                        'type' => 'integer',
                        'default' => '1',
                        'desc' => 'Sets the linewidth of the label sticks.'
                ),
                'labelsAbove' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'If true, values will be shown above the bars. For regular and stacked bar charts units are included, whereas for grouped bar charts they\'re not (usually there isn\'t enough space for them).'
                ),
                'labelsAboveBold' => array(
                        'type' => 'boolean',
                        'default' => 'null (defaults to the textBold setting)',
                        'desc' => 'Whether the labelsAbove labels are bold or not'
                ),
                'labelsAboveItalic' => array(
                        'type' => 'boolean',
                        'default' => 'null (defaults to the textItalic setting)',
                        'desc' => 'Whether the labelsAbove labels are italic or not'
                ),
                'labelsAbovePoint' => array(
                        'type' => 'string',
                        'default' => '.',
                        'desc' => 'The decimal point character for the labels above labels'
                ),
                'labelsAboveThousand' => array(
                        'type' => 'string',
                        'default' => ',',
                        'desc' => 'The thousand separator character for the labels above labels'
                ),
                'labelsAboveFormatter' => array(
                        'type' => 'string',
                        'default' => 'eg:',
                        'desc' => 'This can be a function that handles the formatting of the numbers'
                ),
                'labelsAboveOffsetx' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'If you want to alter the position of the labels in the horizontal direction you can use this property'
                ),
                'labelsAboveTotalFont' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The font to use when rendering the final labelsAbove label'
                ),
                'labelsAboveTotalSize' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'The size of the final labelsAbove label'
                ),
                'labelsAboveTotalColor' => array(
                        'type' => 'string',
                        'default' => 'This can be either a string defining a single color or an array of two strings - one for the up color, one for the down color',
                        'desc' => 'The color of the final labelsAbove label'
                ),
                'labelsAboveTotalBold' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the final labelsAbove label is bold or not'
                ),
                'labelsAboveTotalItalic' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the fnal labelsAbove label is italic or not'
                ),
                'labelsAboveTotalDecimals' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'The number of decimals that are displayed on the final label'
                ),
                'labelsAboveTotalUnitsPre' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'A string that is appended to the number on the final labelsAbove label'
                ),
                'labelsAboveTotalUnitsPost' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'A string that is prepended to the number on the final labelsAbove label'
                ),
                'labelsAboveTotalPoint' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'This can be a character (or multiple characters) that is to be used as the decimal separator in the final label'
                ),
                'labelsAboveTotalThousand' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'This can be a character (or multiple characters) that is to be used as the thousand separator in the final label'
                ),
                'labelsAboveTotalFormatter' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'This can be a function that handles the formatting of the final number'
                ),
                'labelsAboveFormatterX' => array(
                        'type' => 'string',
                        'default' => 'null, An example function to format a datetime value is',
                        'desc' => 'If you need to format the X value then you can use this function to do so'
                ),
                'labelsAboveFormatterY' => array(
                        'type' => 'string',
                        'default' => 'null, An example function to format a datetime value is',
                        'desc' => 'If you need to format the X value then you can use this function to do so'
                ),
                'labelsInbarBold' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the inbar labels are bold or not'
                ),
                'labelsInbarItalic' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the inbar labels are italic or not'
                ),
                'labelsComplete' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'This allows you to turn off the percent complete indicator if you want to'
                ),
                'labelsCompleteFont' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The font used to render the percent-complete number'
                ),
                'labelsCompleteSize' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'The size of the text'
                ),
                'labelsCompleteColor' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The color of the text'
                ),
                'labelsCompleteBold' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the text is bold or not'
                ),
                'labelsCompleteItalic' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the text is italic or not'
                ),
                'labelsIngraphBold' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the ingraph labels are bold or not'
                ),
                'labelsIngraphItalic' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the ingraph labels are italic or not'
                ),
                'labelsAboveDecimals' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'This stipulates how many decimals are used in the above bar labels.'
                ),
                'labelsAboveUnitsPre' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The units to put on the above labels. These are positioned BEFORE the number'
                ),
                'labelsAboveUnitsPost' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The units to put on the above labels. These are positioned AFTER the number'
                ),
                'labelsAboveSize' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'The font size of the above bar labels. Useful if you only have a few bars.'
                ),
                'labelsAboveColor' => array(
                        'type' => 'string',
                        'default' => 'null, defaults to text.color setting',
                        'desc' => 'The color of the above bar labels.'
                ),
                'labelsAboveFont' => array(
                        'type' => 'string',
                        'default' => 'Same as text.font',
                        'desc' => 'The font used to render the labels.'
                ),
                'labelsAboveBackground' => array(
                        'type' => 'string',
                        'default' => 'null, defaults to text.color setting',
                        'desc' => 'The background color of the labels.'
                ),
                'labelsAboveBorder' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'Whether the labels have a border or not.'
                ),
                'labelsAboveOffsety' => array(
                        'type' => 'integer',
                        'default' => '5',
                        'desc' => 'The Y offset of the label from the point on the line.'
                ),
                'labelsAboveAngle' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'You can use this to angle the text shown above the bars. It can be anything from -90 to 90 (degrees).'
                ),
                'labelsAboveSpecific' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'null',
                        'desc' => 'If instead of the values you want to show arbitrary text - you can with this. It should be an arry of the labels to be shown.'
                ),
                'labelsAngled' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'false',
                        'desc' => 'Whether angled labels are enabled or not. These labels are drawn above the line, not the points that the line connects. You can have different text styles for up, down and level labels. All of the text configuration properties eventually fall back to the text* text styles. The property should be an array that contains three strings - the label for up, the label for down and the label for level, like this: labelsAngled: [&quot;Up label&quot;, &quot;Down label&quot;, &quot;Level label&quot;] However, if you are also setting the labelsAngledSpecific property then this can simply be set to true.'
                ),
                'labelsAngledSpecific' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'null',
                        'desc' => 'Use this property to specify the exact labels that are spread across the line. The should be one less label than the number of points on your line. If you set this the labelsAngled property can be just set to true.'
                ),
                'labelsAngledAccessible' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Use this to set whether the labelsAbove labels should be drawn using accessible text (the default) or by using native canvas text. When the chart has the adjustable property enabled the labelsAngled labels are always drawn using native canvas text.'
                ),
                'labelsAngledFont' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The font used by the labelsAngled labels. If not specified this falls back to the textFont property.'
                ),
                'labelsAngledColor' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The color used by the labelsAngled labels. If not specified this falls back to the textColor property.'
                ),
                'labelsAngledSize' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'The size used by the labelsAngled labels. If not specified this falls back to the textSize property.'
                ),
                'labelsAngledBold' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the labelsAbove labels are bold or not. If not specified this falls back to the textBold property.'
                ),
                'labelsAngledItalic' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the labelsAbove labels are italic or not. If not specified this falls back to the textItalic property.'
                ),
                'labelsAngledUpFont' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The font used by the labelsAngled labels that have an upward direction. If not specified this falls back to the labelsAngledFont property. '
                ),
                'labelsAngledUpColor' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The color used by the labelsAngled labels that have an upward direction. If not specified this falls back to the labelsAngledColor property. '
                ),
                'labelsAngledUPSize' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'The size used by the labelsAngled labels that have an upward direction. If not specified this falls back to the labelsAngledSize property. '
                ),
                'labelsAngledUPBold' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the labelsAbove labels are bold or not when the labels have an upward direction. If not specified this falls back to the labelsAngledBold property. '
                ),
                'labelsAngledUPItalic' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the labelsAbove labels are italic or not when the labels have an upward direction. If not specified this falls back to the labelsAngledItalic property. '
                ),
                'labelsAngledDownFont' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The font used by the labelsAngled labels that have a downward direction. If not specified this falls back to the labelsAngledFont property. '
                ),
                'labelsAngledDownColor' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The color used by the labelsAngled labels that have a downward direction. If not specified this falls back to the labelsAngledColor property. '
                ),
                'labelsAngledDownSize' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'The size used by the labelsAngled labels that have a downward direction. If not specified this falls back to the labelsAngledSize property. '
                ),
                'labelsAngledDownBold' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the labelsAbove labels are bold or not when the labels have a downward direction. If not specified this falls back to the labelsAngledBold property. '
                ),
                'labelsAngledDownItalic' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the labelsAbove labels are italic or not when the labels have a downward direction. If not specified this falls back to the labelsAngledItalic property. '
                ),
                'labelsAngledLevelFont' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The font used by the labelsAngled labels that are level (not upward and not downward). If not specified this falls back to the labelsAngledFont property. '
                ),
                'labelsAngledLevelColor' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The color used by the labelsAngled labels that are level (not upward and not downward). If not specified this falls back to the labelsAngledColor property. '
                ),
                'labelsAngledLevelSize' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'The size used by the labelsAngled labels that are level (not upward and not downward). If not specified this falls back to the labelsAngledSize property. '
                ),
                'labelsAngledLevelBold' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => '	Whether the labelsAbove labels are bold or not when the labels are level (not upward and not downward). If not specified this falls back to the labelsAngledBold property. '
                ),
                'labelsAngledLevelItalic' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the labelsAbove labels are italic or not when the labels are level (not upward and not downward). If not specified this falls back to the labelsAngledItalic property. '
                ),
                'labelsIngraph' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'null',
                        'desc' => 'An array of labels for the chart which are drawn \'inside\' the chart. If you have 5 data points then this should have a corresponding number of elements'
                ),
                'labelsIngraphBounding' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'Whether the in-graph labels are surrounded by a bounding box'
                ),
                'labelsIngraphBoundingFill' => array(
                        'type' => 'string',
                        'default' => 'white',
                        'desc' => 'The fill color of the bounding square'
                ),
                'labelsIngraphUnitsPre' => array(
                        'type' => 'string',
                        'default' => 'null (empty string)',
                        'desc' => 'This string is PREPENDED to the label'
                ),
                'labelsIngraphUnitsPost' => array(
                        'type' => 'string',
                        'default' => 'null (empty string)',
                        'desc' => 'This string is APPENDED to the label'
                ),
                'labelsIngraphRadius' => array(
                        'type' => 'double',
                        'default' => 'null',
                        'desc' => 'If specified this is the radius that the labels are positioned at. If its a number between 0 and 2 it is MULTIPLIED with the radius to get the position. If its above 2 though its used as the EXACT radius'
                ),
                'labelsIngraphColor' => array(
                        'type' => 'string',
                        'default' => 'null (empty string)',
                        'desc' => 'The color of the labels.'
                ),
                'labelsIngraphFont' => array(
                        'type' => 'string',
                        'default' => 'Same as text.font',
                        'desc' => 'The font to use for the ingraph labels.'
                ),
                'labelsIngraphSize' => array(
                        'type' => 'integer',
                        'default' => 'Same as text.size',
                        'desc' => 'The font size of the ingraph labels'
                ),
                'labelsIngraphSpecific' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'Instead of the values you use this option to specify the text that is shown'
                ),
                'labelsCenter' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'If you have a donut chart this can show a label in the center'
                ),
                'labelsCenterSize' => array(
                        'type' => 'integer',
                        'default' => '26',
                        'desc' => 'The size of the center label'
                ),
                'labelsCenterFont' => array(
                        'type' => 'string',
                        'default' => 'Arial',
                        'desc' => 'The font used to render the label'
                ),
                'labelsCenterColor' => array(
                        'type' => 'string',
                        'default' => 'black',
                        'desc' => 'The color of the center label'
                ),
                'labelsCenterItalic' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Whether the center label is italic'
                ),
                'labelsCenterBold' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Whether the center label is bold'
                ),
                'labelsAxes' => array(
                        'type' => 'string',
                        'default' => 'nsew',
                        'desc' => 'This controls the axes that show the scale labels. Each letter stands for the appropriate axis (North, South, East and West)'
                ),
                'labelsAxesBackground' => array(
                        'type' => 'string',
                        'default' => 'rgba(255,255,255,0.8)',
                        'desc' => 'This is the color of the background for the labels.'
                ),
                'labelsPosition' => array(
                        'type' => 'string',
                        'default' => 'center',
                        'desc' => ' For Rose Charts this can be either center or edge and determines the position of the labels.'
                ),
                'labelsCount' => array(
                        'type' => 'integer',
                        'default' => '5',
                        'desc' => 'This determines the number of labels that are displayed on the axes'
                ),
                'labelsFont' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The font used to render the labels'
                ),
                'labelsSize' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'The size of the labels'
                ),
                'labelsItalic' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the labels are italic or not'
                ),
                'labelsList' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'A new way of organising the labels - this should help avoid label text overlaps'
                ),
                'labelsIngraphBoundingStroke' => array(
                        'type' => 'string',
                        'default' => 'rgba(0,0,0,0)',
                        'desc' => 'The stroke color of the bounding square'
                ),
                'labelsIngraphPoint' => array(
                        'type' => 'string',
                        'default' => '.',
                        'desc' => 'The character used as the decimal point'
                ),
                'labelsIngraphThousand' => array(
                        'type' => 'string',
                        'default' => ',',
                        'desc' => 'The character used as the thousand separator'
                ),
                'labelsIngraphDecimals' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'The number of decimals shown on the ingraph labels'
                ),
                'labelsOffsetAngle' => array(
                        'type' => 'double',
                        'default' => '0',
                        'desc' => 'This is the angular offset that the labels are positioned at (measured in radians)'
                ),
                'labelsOffsetRadius' => array(
                        'type' => 'double',
                        'default' => '0',
                        'desc' => 'This is the radial offset the labels are positioned at'
                ),
                'labelsOffsetx' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'This is the X offset the labels are positioned at'
                ),
                'labelsOffsety' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'This is the Y offset the labels are positioned at'
                ),
                'labelsSpecific' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'null',
                        'desc' => 'If you don\'t want a scale and want specific labels instead, you pass an array of labels using this property instead'
                ),
                'labelsCentered' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'This controls whether the labels are centered horizontally and vertically'
                ),
                'labelsValue' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'This allows you to show a text label under the pointer (by default) that tells you what the value is'
                ),
                'labelsValueDecimals' => array(
                        'type' => 'integer',
                        'default' => '0 (defaults to scaleDecimals)',
                        'desc' => 'With this you can specify how many decimals that you want displayed'
                ),
                'labelsValueBounding' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'This allows you to turn completely off the bounding box'
                ),
                'labelsValueBoundingStroke' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'This allows you to set the fill color of the label. If you don\'t want a border you can set it to transparent: rgba(0,0,0,0) black.'
                ),
                'labelsValueBoundingFill' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'This allows you to set the fill color of the label. If you don\'t want the label filled you can set it to transparent: rgba(0,0,0,0) white.'
                ),
                'labelsValueUnitsPre' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'Units that are added to the center label (before the number)'
                ),
                'labelsValueUnitsPost' => array(
                        'type' => 'string',
                        'default' => 'null (an empty string)',
                        'desc' => 'Units that are added to the center label (after the number)'
                ),
                'labelsValueFont' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The font to use for the value text label'
                ),
                'labelsValueSize' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'The size to use for the value text label'
                ),
                'labelsValueItalic' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the value text label is italic or not'
                ),
                'labelsValueBold' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the value text label is bold or not'
                ),
                'labelsValueColor' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The color to use for the value text label'
                ),
                'labelsValueText' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'This option controls whether the value of the Meter is shown in text'
                ),
                'labelsValueTextDecimals' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'The amount of decimals shown in the text label'
                ),
                'labelsValueTextUnitsPre' => array(
                        'type' => 'string',
                        'default' => 'An empty string',
                        'desc' => 'The units (before the value) shown in the text label'
                ),
                'labelsValueTextUnitsPost' => array(
                        'type' => 'string',
                        'default' => 'An empty string',
                        'desc' => 'The units (after the value) shown in the text label'
                ),
                'labelsValueTextFont' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The font that the text is rendered in'
                ),
                'labelsValueTextSize' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'The size (in points) of the text'
                ),
                'labelsValueTextBold' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the text is bold or not'
                ),
                'labelsValueTextItalic' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'Whether the text is italic or not'
                ),
                'labelsValueTextColor' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The color of the text'
                ),
                'labelsValueTextBackground' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'Whether the text has a background or not'
                ),
                'labelsValueTextBackgroundFill' => array(
                        'type' => 'string',
                        'default' => 'rgba(255,255,255,0.75)',
                        'desc' => 'The color of the background of the text'
                ),
                'labelsValueTextBackgroundStroke' => array(
                        'type' => 'string',
                        'default' => 'rgba(0,0,0,0)',
                        'desc' => 'The stroke color of the background'
                ),
                'labelsValueTextSpecific' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'If you want to specify the label to display on the Meter you can specify it with this property'
                ),
                'labelsMargin' => array(
                        'type' => 'integer',
                        'default' => '35',
                        'desc' => 'The width of the area that labels are put in'
                ),
                'labelsOffset' => array(
                        'type' => 'integer',
                        'default' => '10',
                        'desc' => 'The offset for the labels.'
                ),
                'labelsAxesFont' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The font used by the labels'
                ),
                'labelsAxesSize' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'The size of the labels'
                ),
                'labelsAxesColor' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The color of the labels'
                ),
                'labelsAxesItalic' => array(
                        'type' => 'boolean',
                        'default' => 'null',
                        'desc' => 'This controls whether the axis labels are italic or not'
                ),
                'labelsAxesCount' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'This controls how many scale labels that are displayed'
                ),
                'labelsInbar' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'null',
                        'desc' => 'An array of labels that are drawn inside the Gantt chart bars. These labels can also be drawn on the right of these bars.'
                ),
                'labelsInbarAlign' => array(
                        'type' => 'string',
                        'default' => 'left',
                        'desc' => 'For Gantt chart this controls whether the labels are aligned left, center or right when the labels are drawn inside the bars.'
                ),
                'labelsInbarBgcolor' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'For Gantt chart the background color for the text. By default there\'s no background to the text.'
                ),
                'labelsInbarColor' => array(
                        'type' => 'string',
                        'default' => 'black',
                        'desc' => 'For Gantt chart the color of the labels.'
                ),
                'labelsInbarFont' => array(
                        'type' => 'string',
                        'default' => 'Arial',
                        'desc' => 'For Gantt chart The font used to draw the labels.'
                ),
                'labelsInbarSize' => array(
                        'type' => 'integer',
                        'default' => '10',
                        'desc' => 'For Gantt chart The font size of the text labels.'
                ),
                'labelsInbarAbove' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'For Gantt chart If you prefer, the labels can be drawn \'above\' the bars (actually to the right but for API compatibility it\'s called \'above\').'
                ),
                'title' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The title of the chart'
                ),
                'titleLeft' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The left title of a bipolar chart.'
                ),
                'titleRight' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The right title of a bipolar chart.'
                ),
                'titleLeftFont' => array(
                        'type' => 'string',
                        'default' => 'null ',
                        'desc' => 'The font the left title is rendered in.'
                ),
                'titleLeftSize' => array(
                        'type' => 'integer',
                        'default' => 'null ',
                        'desc' => 'The size of the left titles font.'
                ),
                'titleLeftBold' => array(
                        'type' => 'boolean',
                        'default' => 'null ',
                        'desc' => 'Whether the left title is bold or not.'
                ),
                'titleLeftItalic' => array(
                        'type' => 'boolean',
                        'default' => 'null ',
                        'desc' => 'Whether the left title is italic or not.'
                ),
                'titleLeftColor' => array(
                        'type' => 'string',
                        'default' => 'null ',
                        'desc' => 'The color of the left title.'
                ),
                'titleRightFont' => array(
                        'type' => 'string',
                        'default' => 'null ',
                        'desc' => 'The font that the right title is rendered in.'
                ),
                'titleRightSize' => array(
                        'type' => 'integer',
                        'default' => 'null ',
                        'desc' => 'The size of the right titles font.'
                ),
                'titleRightBold' => array(
                        'type' => 'boolean',
                        'default' => 'null ',
                        'desc' => 'Whether the right title is bold or not.'
                ),
                'titleRightItalic' => array(
                        'type' => 'boolean',
                        'default' => 'null ',
                        'desc' => 'Whether the right title is italic or not.'
                ),
                'titleRightColor' => array(
                        'type' => 'string',
                        'default' => 'null ',
                        'desc' => 'The color of the right title.'
                ),
                'titleFont' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The font that the title is rendered in. If not specified the text.font setting is used (usually Arial)'
                ),
                'titleSize' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'The font size of the title. If not specified the size is usually 2pt bigger than the text.size setting.'
                ),
                'titleBold' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'Whether the title is bold or not.'
                ),
                'titleItalic' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Whether the title is italic or not.'
                ),
                'titleBackground' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'The background color (if any) for the title.'
                ),
                'titleColor' => array(
                        'type' => 'string',
                        'default' => 'black',
                        'desc' => 'The color of the title.'
                ),
                'titleX' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'To give the exact X coordinate for the title - use this'
                ),
                'titleY' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'To give the exact Y coordinate for the title - use this'
                ),
                'shadow' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'Whether a drop shadow is applied.'
                ),
                'shadowColor' => array(
                        'type' => 'string',
                        'default' => '#aaa',
                        'desc' => 'The color of the shadow.'
                ),
                'shadowOffsetx' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'The X offset of the shadow.'
                ),
                'shadowOffsety' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'The Y offset of the shadow.'
                ),
                'shadowBlur' => array(
                        'type' => 'integer',
                        'default' => '15',
                        'desc' => 'The severity of the shadow blurring effect.'
                ),
                'scaleVisible' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Instead of the Full/Empty labels you can set this to true to show a scale instead.'
                ),
                'scaleMax' => array(
                        'type' => 'double',
                        'default' => 'If not specified then it will be calculated',
                        'desc' => 'The optional maximum scale value'
                ),
                'scaleRound' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Whether to round the scale up. eg A maximum value of 59 results in scale to 100.'
                ),
                'scaleDecimals' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'The number of decimal places to display for the Y scale.'
                ),
                'scalePoint' => array(
                        'type' => 'string',
                        'default' => '. (point)',
                        'desc' => 'The character used as the decimal point.'
                ),
                'labelsValuePoint' => array(
                        'type' => 'string',
                        'default' => '. (point)',
                        'desc' => 'The character used as the decimal point.'
                ),
                'scaleThousand' => array(
                        'type' => 'string',
                        'default' => ', (komma)',
                        'desc' => 'The character used as the thousand separator.'
                ),
                'labelsValueThousand' => array(
                        'type' => 'string',
                        'default' => ', (komma)',
                        'desc' => 'The character used as the thousand separator.'
                ),
                'scaleZerostart' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'By default scales don\'t show zero - but you can change that with this option.'
                ),
                'scaleLabelsCount' => array(
                        'type' => 'integer',
                        'default' => '5',
                        'desc' => 'When you\'re showing a scale this controls how many labels are shown'
                ),
                'scaleUnitsPre' => array(
                        'type' => 'string',
                        'default' => 'This string is displayed before the actual number, allowing you to specify values such as €50 ',
                        'desc' => 'The units that the Y axis is measured in'
                ),
                'scaleUnitsPost' => array(
                        'type' => 'string',
                        'default' => 'This string is displayed after the actual number, allowing you to specify values such as 50ms ',
                        'desc' => 'The units that the Y axis is measured in'
                ),
                'outofbounds' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Normally, out-of-bounds values are not drawn. By setting this to true you can change this behaviour.'
                ),
                'outofboundsClip' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'If you\'ve enabled the outofbounds option but you\'re not interested in seeing the bits which fall outside of the chart area (eg in the gutters) then you can enable this option.'
                ),
                'key' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => '[] (An empty array)',
                        'desc' => 'An array of key information'
                ),
                'keyBackground' => array(
                        'type' => 'string',
                        'default' => 'white',
                        'desc' => 'The color of the key background. Typically white, you could set this to something like rgba(255,255,255,0.7) to allow people to see things behind it.'
                ),
                'keyHalign' => array(
                        'type' => 'string',
                        'default' => 'right',
                        'desc' => 'Instead of specifying the exact x/y coordinates, you can use this property to simply specify whether the key hould be aligned left or right.'
                ),
                'keyPosition' => array(
                        'type' => 'string',
                        'default' => 'graph',
                        'desc' => 'Determines the position of the key. Either graph (default), or gutter.'
                ),
                'keyPositionX' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'This allows you to specify a specific X coordinate for the key.'
                ),
                'keyPositionY' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'This allows you to specify a specific Y coordinate for the key.'
                ),
                'keyPositionGraphBoxed' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'If you have the key in graph mode (ie a box), this controls whether it has a border.'
                ),
                'keyShadow' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Whether a small drop shadow is applied to the key.'
                ),
                'keyShadowColor' => array(
                        'type' => 'string',
                        'default' => '#666',
                        'desc' => 'The color of the shadow.'
                ),
                'keyShadowBlur' => array(
                        'type' => 'integer',
                        'default' => '3',
                        'desc' => 'The extent of the blurring effect used on the shadow.'
                ),
                'keyShadowOffsetx' => array(
                        'type' => 'integer',
                        'default' => '2',
                        'desc' => 'The X offset of the shadow.'
                ),
                'keyShadowOffsety' => array(
                        'type' => 'integer',
                        'default' => '2',
                        'desc' => 'The Y offset of the shadow.'
                ),
                'keyRounded' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'This controls whether the corners of the key (in graph mode) are curved. If the key is gutter mode, this has no effect.'
                ),
                'keyColorShape' => array(
                        'type' => 'string',
                        'default' => 'square',
                        'desc' => 'This can be square, circle or line and controls how the color indicators in the key appear.'
                ),
                'keyLinewidth' => array(
                        'type' => 'integer',
                        'default' => '1',
                        'desc' => 'This can be square, circle or line and controls how the color indicators in the key appear.'
                ),
                'keyColors' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'null',
                        'desc' => 'You can use this property to specifically set the colors to be used by the key.'
                ),
                'keyInteractive' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'By setting this to true you can make the key clickble - thus highlighting the chosen item.'
                ),
                'keyInteractiveHighlightChartFill' => array(
                        'type' => 'string',
                        'default' => 'rgba(255,255,255,0.7)',
                        'desc' => 'Using this property you can set the color used to highlight when the interactive key is clicked.'
                ),
                'keyInteractiveHighlightChartStroke' => array(
                        'type' => 'string',
                        'default' => 'black',
                        'desc' => 'Using this property you can set the color used to highlight when the interactive key is clicked.'
                ),
                'keyPositionMarginBoxed' => array(
                        'type' => 'boolean',
                        'default' => 'false ',
                        'desc' => 'When the key is in margin mode this determines if it sits in a box.'
                ),
                'keyLabelsFont' => array(
                        'type' => 'string',
                        'default' => '[same as the textFont setting] ',
                        'desc' => 'The font used for the key text.'
                ),
                'keyLabelsSize' => array(
                        'type' => 'integer',
                        'default' => '[same as the textSize setting] ',
                        'desc' => 'The size of the text in the key.'
                ),
                'keyLabelsColor' => array(
                        'type' => 'string',
                        'default' => 'black ',
                        'desc' => 'The color of the text in the key.'
                ),
                'keyLabelsBold' => array(
                        'type' => 'boolean',
                        'default' => 'false ',
                        'desc' => 'Whether the text in the key is bold or not.'
                ),
                'keyLabelsItalic' => array(
                        'type' => 'boolean',
                        'default' => 'false ',
                        'desc' => 'Whether the text in the key is italic or not.'
                ),
                'keyLabelsOffsetx' => array(
                        'type' => 'integer',
                        'default' => '0 ',
                        'desc' => 'The offset that gets applied to the X coordinate to the key text.'
                ),
                'keyLabelsOffsety' => array(
                        'type' => 'integer',
                        'default' => '0 ',
                        'desc' => 'The offset that gets applied to the Y coordinate to the key text.'
                ),
                'keyTextAccessible' => array(
                        'type' => 'boolean',
                        'default' => 'null ',
                        'desc' => 'By default the key text IS NOT accessible but by using this setting you can override this.'
                ),
                'contextmenu' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => '[] (An empty array)',
                        'desc' => 'An array of context menu items'
                ),
                'tooltips' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'Null',
                        'desc' => 'A numerically indexed array of tooltips that are shown when a bar is clicked. These can contain HTML.'
                ),
                'tooltipsDataset' => array(
                        'type' => 'string',
                        'default' => 'null ',
                        'desc' => 'Instead of having one tooltip for each point on your chart you can use this property to have one tooltip per line. So if you have four lines you can set this to an array of four strings - one for each line. You can click anywhere on the line to see it. There\'s a demo in the download archive called line-tooltips-dataset.html'
                ),
                'tooltipsDatasetEvent' => array(
                        'type' => 'string',
                        'default' => 'click ',
                        'desc' => 'This can be set to click or mousemove and determines which event causes the tooltip to be shown.'
                ),
                'tooltipsEffect' => array(
                        'type' => 'string',
                        'default' => 'slide',
                        'desc' => 'The effect used for showing tooltips. Can be either fade, slide or none.'
                ),
                'tooltipsEvent' => array(
                        'type' => 'string',
                        'default' => 'onclick',
                        'desc' => 'This is the event that triggers the tooltips. It can be either onclick or onmousemove'
                ),
                'tooltipsCssClass' => array(
                        'type' => 'string',
                        'default' => 'RGraph_tooltip',
                        'desc' => 'This is the name of the CSS class the chart uses.'
                ),
                'tooltipsHighlight' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'Set this to false if you don\'t want your charts to be highlighted.'
                ),
                'tooltipsHotspot' => array(
                        'type' => 'integer',
                        'default' => '3',
                        'desc' => 'This controls the size of the hotspot on the chart for tooltips.'
                ),
                'tooltipsHotspotSize' => array(
                        'type' => 'integer',
                        'default' => '5',
                        'desc' => 'The size of the hotspot area for tooltips.'
                ),
                'tooltipsHotspotXonly' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'If set to true the hotspot for the tooltips will ignore the height of the bar and extend from top gutter down to the bottom gutter. This can be useful when you have zero value bars but still want to see the tooltips.'
                ),
                'tooltipsNohideonclear' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Not an option that you\'ll need particularly often if at all. Setting this to true means that when you call the RGraph.clear() API function tooltip DO NOT get hidden.'
                ),
                'tooltipsOverride' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'If you wish to handle showing tooltips yourself, this should be a function object which does just that.'
                ),
                'tooltipsFormattedPoint' => array(
                        'type' => 'string',
                        'default' => '. ',
                        'desc' => 'When using formatted tooltip strings this is used as the point when using the %{value_formatted} option.'
                ),
                'tooltipsFormattedThousand' => array(
                        'type' => 'string',
                        'default' => ',',
                        'desc' => 'When using formatted tooltip strings this is used as the thousand separator when using the %{value_formatted} option.'
                ),
                'tooltipsFormattedDecimals' => array(
                        'type' => 'integer',
                        'default' => '0 ',
                        'desc' => 'When using formatted tooltip strings this specifies the number of decimals when using the %{value_formatted} option.'
                ),
                'tooltipsFormattedUnitsPre' => array(
                        'type' => 'string',
                        'default' => '(an empty string) ',
                        'desc' => 'When using formatted tooltip strings these units are prepended to the number when using the %{value_formatted} option.'
                ),
                'tooltipsFormattedUnitsPost' => array(
                        'type' => 'string',
                        'default' => '(an empty string) ',
                        'desc' => 'When using formatted tooltip strings these units are appended to the number when using the %{value_formatted} option.'
                ),
                'tooltipsFormattedKeyColors' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'null ',
                        'desc' => 'When using formatted tooltip strings you can give specific colors for the %{key} option to use.'
                ),
                'tooltipsFormattedKeyColorsShape' => array(
                        'type' => 'string',
                        'default' => 'square ',
                        'desc' => 'This is the shape that\'s used in the tooltip key. It can be square or circle'
                ),
                'tooltipsFormattedKeyLabels' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => '[] (an empty array) ',
                        'desc' => 'When using formatted tooltip strings these are the labels that are displayed.'
                ),
                'tooltipsCss' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => '[] (an empty array) ',
                        'desc' => 'If you want to specify some CSS that gets applied to all of the tooltips, but don\'t want to use the RGraph.tooltips.style object (which gets applied to all of the tooltips on the page for every chart) you can use this property to give some per-object CSS for the tooltips. These are CSS styles that get applied to all of the tooltips for the specific object only. It should look like this: '
                ),
                'tooltipsOffsetx' => array(
                        'type' => 'integer',
                        'default' => '0 ',
                        'desc' => 'This property allows you to shift the tooltips left or right.'
                ),
                'tooltipsOffsety' => array(
                        'type' => 'integer',
                        'default' => '0 ',
                        'desc' => 'This property allows you to shift the tooltips up or down.'
                ),
                'tooltipsPointer' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'This property allows you to add arraow to tooltip popup.'
                ),
                'tooltipsPointerCss' => array(
                        'type' => 'array',
                        'default' => '[] (an empty array) ',
                        'desc' => 'If you want any CSS values applied to the tooltips pointer (for example a CSS border) then specify an object containing those values to this property.'
                ),
                'tooltipsPositionStatic' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'This property sets tooltips positions.'
                ),
                'crosshairs' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'If true, you will get a crosshair centering on the current mouse position.'
                ),
                'crosshairsLinewidth' => array(
                        'type' => 'integer',
                        'default' => '1',
                        'desc' => 'This controls the linewidth of the crosshairs.'
                ),
                'crosshairsColor' => array(
                        'type' => 'string',
                        'default' => '#333',
                        'desc' => 'The color of the crosshairs.'
                ),
                'crosshairsHline' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'This determines whether the horizontal crosshair is shown.'
                ),
                'crosshairsVline' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'This determines whether the vertical crosshair is shown.'
                ),
                'crosshairsCoords' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'If true, this will show the coordinates that the crosshairs are currently over.'
                ),
                'crosshairsCoordsFixed' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'If true, this makes the coordinates static (attached), instead of following the pointer around.'
                ),
                'crosshairsCoordsLabelsX' => array(
                        'type' => 'string',
                        'default' => 'X',
                        'desc' => 'Instead ox X and Y, you can specify more meaningful labels.'
                ),
                'crosshairsCoordsLabelsY' => array(
                        'type' => 'string',
                        'default' => 'Y',
                        'desc' => 'Instead ox X and Y, you can specify more meaningful labels.'
                ),
                'crosshairsCoordsFormatterX' => array(
                        'type' => 'string',
                        'default' => 'null, Simply return the value that you wish to be displayed',
                        'desc' => 'This can be a function with which you can format the value to appear just as you want'
                ),
                'crosshairsCoordsFormatterY' => array(
                        'type' => 'string',
                        'default' => 'null, Simply return the value that you wish to be displayed',
                        'desc' => 'This can be a function with which you can format the value to appear just as you want'
                ),
                'annotatable' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Whether annotations are enabled for the chart (ie you can draw on the chart interactively.'
                ),
                'annotatableColor' => array(
                        'type' => 'string',
                        'default' => 'black',
                        'desc' => 'If you do not allow the use of the palette, then this will be the only color allowed for annotations'
                ),
                'annotatableLinewidth' => array(
                        'type' => 'integer',
                        'default' => '1',
                        'desc' => 'This is the linewidth of the annotations'
                ),
                'adjustable' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'This determines whether your chart component will be adjustable.'
                ),
                'adjustableOnly' => array(
                        'type' => 'array',
                        'types' => 'boolean',
                        'default' => 'A truthy value for when it is, a falsey value for when it\'s not',
                        'desc' => 'This should be an array of values that determine whether a point is adjustable or not'
                ),
                'circle' => array(
                        'type' => 'double',
                        'default' => '0',
                        'desc' => 'What value to draw a circle at. Defaults to zero (off). You could use this to represent a threshold of some sort.'
                ),
                'circleFill' => array(
                        'type' => 'string',
                        'default' => 'red',
                        'desc' => 'What color to fill the circle with.'
                ),
                'circleStroke' => array(
                        'type' => 'string',
                        'default' => 'black',
                        'desc' => 'What color to stroke (ie The outline) the circle with.'
                ),
                'accumulative' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'If set to true this will produce a \'stacked\' Radar chart. Obviously you must have two or more data sets, and also the data sets must have the same number of data points.'
                ),
                'tickmarks' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'What kind of tickmarks to use on the chart. This can be:  circle, filledcircle, endcircle, square, endsquare, filledsquare, filledendsquare, tick, halftick, endtick, cross, dot, borderedcircle (same as dot), arrow, filledarrow, triangle, filledtriangle.'
                ),
                'tickmarksColor' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => '	The color of the tickmarks. If null then it will default to the same color as the Line.'
                ),
                'tickmarksStyle' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'What kind of tickmarks to use on the chart'
                ),
                'tickmarkSize' => array(
                        'type' => 'integer',
                        'default' => '3',
                        'desc' => 'The size of the tickmarks'
                ),
                'tickmarksStyleDotStroke' => array(
                        'type' => 'string',
                        'default' => 'null (defaults to the line color)',
                        'desc' => 'This is the color of the filled part of the dot/borderedcircle style tickmarks'
                ),
                'tickmarksStyleDotFill' => array(
                        'type' => 'string',
                        'default' => 'null (defaults to the line color)',
                        'desc' => 'This is the color of the stroked part of the dot/borderedcircle style tickmarks'
                ),
                'tickmarksStyleDotLinewidth' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'This is the width of the line used when drawing the tickmarks'
                ),
                'tickmarksStyleImageHalign' => array(
                        'type' => 'string',
                        'default' => 'center',
                        'desc' => 'This can be left right or center and determines the horizontal alignment of the tickmark'
                ),
                'tickmarksStyleImageValign' => array(
                        'type' => 'string',
                        'default' => 'center',
                        'desc' => 'This can be top bottom or center and determines the vertical alignment of the tickmark'
                ),
                'tickmarksStyleImageOffsetx' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'After the alignment has been applied, this is added to the X coordinate of the tickmark'
                ),
                'tickmarksStyleImageOffsety' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'After the alignment has been applied, this is added to the Y coordinate of the tickmark'
                ),
                'tickmarksLarge' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'The number of big tickmarks on the chart'
                ),
                'tickmarksLargeColor' => array(
                        'type' => 'string',
                        'default' => 'black',
                        'desc' => 'The color of the big tickmarks on the chart'
                ),
                'stepped' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Draws the line as stepped. Useful for showing stock performance for example.'
                ),
                'linewidth' => array(
                        'type' => 'double',
                        'default' => '1.0',
                        'desc' => 'Sets the line width.'
                ),
                'animationUnfoldX' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'This is used by the Unfold Line chart animation and dictates whether the X value is unfolded.'
                ),
                'animationUnfoldY' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'This is used by the Unfold Line chart animation and dictates whether the Y value is unfolded.'
                ),
                'animationUnfoldInitial' => array(
                        'type' => 'integer',
                        'default' => '2',
                        'desc' => 'This property can be used to set the initial factor for the Unfold animation. Setting this to a value less than one will cause the line to expand outwards, whilst a value greater than one will cause the line to contract towards the correct values.'
                ),
                'highlights' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'Different to tooltip highlighting this adds circular points to the Radar chart.'
                ),
                'highlightsRadius' => array(
                        'type' => 'double',
                        'default' => '3',
                        'desc' => 'The radius of the highlights. In other words this controls the size of the highlights.'
                ),
                'highlightStroke' => array(
                        'type' => 'string',
                        'default' => 'black',
                        'desc' => 'If you use tooltips, this controls the colour of the highlight stroke.'
                ),
                'highlightStyle' => array(
                        'type' => 'string',
                        'default' => '3d',
                        'desc' => 'With Pie charts can be either explode, 2d or 3d and determines which style of segment highlighting is used in conjunction with tooltips.'
                ),
                'highlightFill' => array(
                        'type' => 'string',
                        'default' => 'rgba(255,255,255,0.5)',
                        'desc' => 'If you use tooltips, this controls the colour of the highlight fill.'
                ),
                'highlightPointRadius' => array(
                        'type' => 'double',
                        'default' => '2',
                        'desc' => 'This controls the size of the highlight when tooltips are used.'
                ),
                'highlightStyleOutlineWidth' => array(
                        'type' => 'integer',
                        'default' => '10',
                        'desc' => 'When outline highlighting for tooltips is used, this controls the width of the highlighting band'
                ),
                'highlightStyleTwodFill' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'When 2D highlighting for tooltips is used, this controls the color of the highlighting. The former name for this property was highlightStyleTwodColor.'
                ),
                'highlightStyleTwodStroke' => array(
                        'type' => 'string',
                        'default' => 'rgba(255,255,255,0)',
                        'desc' => 'When 2D highlighting for tooltips is used, this controls the stroke color of the highlighting'
                ),
                'highlightStyleTwodLinewidth' => array(
                        'type' => 'integer',
                        'default' => '1 ',
                        'desc' => 'When 2D highlighting for tooltips is used, this controls the linewidth of the highlighting stroke.'
                ),
                'exploded' => array(
                        'type' => 'array',
                        'types' => 'integer',
                        'default' => '[] empty array',
                        'desc' => 'This can either be an array with the same number of elements as segments, or a single number, in which case every segment will be exploded that amount. If it\'s an array then only those segments will be exploded. for Rose Charts this stipulates the exploded value for a segment. It can either be a number which is applied to all segments, or an array of seperate values (eg [15,0,20,25]). The values are the distance from the center that the segment is.'
                ),
                'segmentHighlight' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'For Rose Charts If you wish you can have segments of the chart highlight as you move the mouse around.'
                ),
                'segmentHighlightCount' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'For Rose Charts The number of segments by default corresponds to the number of \'radials\' that the background grid has but using this property you can set it explicitly.'
                ),
                'segmentHighlightFill' => array(
                        'type' => 'string',
                        'default' => 'rgba(0,255,0,0.5)',
                        'desc' => 'For Rose Charts The fill color of the highlight.'
                ),
                'segmentHighlightStroke' => array(
                        'type' => 'string',
                        'default' => 'rgba(0,0,0,0)',
                        'desc' => 'For Rose Charts The stroke color of the highlight.'
                ),
                'spline' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'This option causes the line to be drawn as a spline - ie curvy. Not all options will work with splines - however the introduction of real splines over the previous curvy option is a significant improvement. The line chart on the front page of the website shows this option. Null values will not work with spline.'
                ),
                'clearto' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'This is used in animations and effects as the default color to use when the canvas.'
                ),
                'centerpin' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'If you choose a linewidth greater than 1 or 2 then because of the way that HTML5 canvas renders lines you may end up with visible edges to them. So by using a centerpin you can hide these. This setting should be a number and is used as the radius of the centerpin.'
                ),
                'centerpinStroke' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'This is used as the stroke style of the centerpin.'
                ),
                'centerpinFill' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'This is used as the fill style of the centerpin.'
                ),
                'bevelled' => array(
                        'type' => 'boolean',
                        'default' => 'false',
                        'desc' => 'If true the bars will be given a 3D bevelled appearance'
                ),
                'variant' => array(
                        'type' => 'string',
                        'default' => 'depends on chart type',
                        'desc' => 'This simply stipulates whether you want a regular bar chart, a dot chart, a pyramid chart a 3D chart, a sketch or a glassy chart. Possible values are:  bar, dot, pyramid, arrow, 3d, sketch, glass. The pyramid, dot, arrow, sketch and glass variants are only effective for regular bar charts - not grouped or stacked charts. <p>For horizontal bars you may use hbar (default) or 3d.</p><p>For Bipolar Charts you may specify bipolar (default) or 3d.</p><p>For pie charts this can be either pie (the default), pie3d, donut or donut3d. Setting this to donut or donut3d is how you get a donut chart.</p><p>For rose charts This option can be either stacked (the default) or non-equi-angular. Just because this option is set to stacked does not automatically mean your chart is stacked. If you don\'t suppy the appropriate data you chart may well appear as a regular Rose chart. You may specify 3d, stacked3d or non-equi-angular3d.</p><p>For line charts at present this can only be 3d, and gives a small 3D effect'
                ),
                'variantThreedDepth' => array(
                        'type' => 'integer',
                        'default' => '10',
                        'desc' => 'This is the depth/thickness of the Rose chart when in 3D mode. Using larger depths can make the labels be drawn over the labels.'
                ),
                'variantDonutWidth' => array(
                        'type' => 'integer',
                        'default' => 'null',
                        'desc' => 'This allows you to set how wide the donut is. It can be useful when nesting donuts.'
                ),
                'variantThreedOffsetx' => array(
                        'type' => 'integer',
                        'default' => '10',
                        'desc' => 'his determines the size of the offset in the X direction'
                ),
                'variantThreedOffsety' => array(
                        'type' => 'integer',
                        'default' => '5',
                        'desc' => 'This determines the size of the offset in the Y direction'
                ),
                'variantThreedXaxis' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'This allows you to turn on/off the threed X axis'
                ),
                'variantThreedYaxis' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'This allows you to turn on/off the threed Y axis'
                ),
                'variantThreedAngle' => array(
                        'type' => 'double',
                        'default' => 'null',
                        'desc' => 'This allows you to adjust your 3d x-axis'
                ),
                'grouping' => array(
                        'type' => 'string',
                        'default' => 'grouped',
                        'desc' => 'How the bars are grouped, and it should be one of: grouped or stacked.'
                ),
                'borders' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'for Gantt chart whether a border is shown on the event bars.'
                ),
                'errorbars' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'false',
                        'desc' => 'This should be an array of errorbar information or it can simply be a number instead.'
                ),
                'errorbarsLinewidth' => array(
                        'type' => 'integer',
                        'default' => '1',
                        'desc' => 'This is the linewidth of the errorbars.'
                ),
                'errorbarsColor' => array(
                        'type' => 'string',
                        'default' => 'black',
                        'desc' => 'This is the color of the errorbars. You can also override the color in the errorbar array.'
                ),
                'errorbarsCapped' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'This dictates whether the errorbars have caps on their ends or not.'
                ),
                'errorbarsCappedWidth' => array(
                        'type' => 'integer',
                        'default' => '14',
                        'desc' => 'This is the width of the caps (in total) on the end of the errorbar.'
                ),
                'combinedEffect' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'Set this to the name of an effect (eg grow ) and the CombinedChart object will use that effect to draw the chart instead of the regular draw() function.'
                ),
                'combinedEffectOptions' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'This should be a STRING that contains a JavaScript object of options for the effect function.'
                ),
                'combinedEffectCallback' => array(
                        'type' => 'string',
                        'default' => 'null',
                        'desc' => 'A function that runs when this objects effect has conpleted.'
                ),
                'trendline' => array(
                        'type' => 'array',
                        'types' => 'boolean',
                        'default' => 'false ',
                        'desc' => 'If desired, RGraph can generate a \'best-fit\' trend line for your data. This can be both a boolean or an array of boolean values for when you have multiple datasets.'
                ),
                'trendlineColors' => array(
                        'type' => 'array',
                        'types' => 'string',
                        'default' => 'black ',
                        'desc' => 'Use this property to specify  an array of colors for the trend line(s).'
                ),
                'trendlineLinewidth' => array(
                        'type' => 'array',
                        'types' => 'integer',
                        'default' => '1 ',
                        'desc' => 'Use this property to specify the linewidth of the trend line(s). It can be a single number or an array of numbers if you have multiple datasets.'
                ),
                'trendlineMargin' => array(
                        'type' => 'array',
                        'types' => 'integer',
                        'default' => '25 ',
                        'desc' => 'Use this property to specify the margin of the trend line(s). It can be a single number or an array of numbers if you have multiple datasets.'
                ),
                'trendlineDashed' => array(
                        'type' => 'boolean',
                        'default' => 'true ',
                        'desc' => 'If true then the trend lines on the chart will be dashed.'
                ),
                'trendlineDotted' => array(
                        'type' => 'boolean',
                        'default' => 'false ',
                        'desc' => 'If true then the trend lines on the chart will be dotted,'
                ),
                'trendlineDashArray' => array(
                        'type' => 'array',
                        'types' => 'integer',
                        'default' => 'null ',
                        'desc' => 'If you want to give your own style of dashes then you can with this. It should be an array containing numbers - alternating between the length of a dash and the length of a gap after the dash.'
                ),
                'trendlineClip' => array(
                        'type' => 'boolean',
                        'default' => 'null ',
                        'desc' => 'If set to false then the chart will not be clipped to the area that the tickmarks are located in. This means that the trend line will cover the whole of the chart area (albeit with a small margin and you can turn this off with the trendlineMargin property).'
                ),
                'icon' => array(
                        'type' => 'string',
                        'default' => 'Default: [A data: URL of a fuel icon]',
                        'desc' => 'For Gauge Charts this should be a URL that represents the image to use as the icon on the chart. The default fuel icon is a data: URL, though you can specify any valid image URL.'
                ),
                'iconRedraw' => array(
                        'type' => 'boolean',
                        'default' => 'true',
                        'desc' => 'If false, then the chart is NOT redrawn when the image/icon loads. You may need to set this to false if you use adjusting.'
                ),
                'barOffsetx' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'This is the positioning offset that is applied to the bars (in the horizontal direction)'
                ),
                'barOffsety' => array(
                        'type' => 'integer',
                        'default' => '0',
                        'desc' => 'This is the positioning offset that is applied to the bars (in the vertical direction)'
                ),
                'needleRadiusOffset' => array(
                        'type' => 'integer',
                        'default' => 'r45',
                        'desc' => 'By increasing this you can shorten the needle and by decreasing it you can lengthen the needle'
                )
        );
        if ($option == null)
            return $valid_options;
        else
        {
            if (isset($valid_options[$option]))
                return $valid_options[$option];
            else
                return - 1;
        }
    }
}
